/**
 * Implement Gatsby's Node APIs in this file.
 *
 * See: https://www.gatsbyjs.com/docs/node-apis/
 */
const { error } = require("console")
const semver = require("semver")
const package_json = require("./package.json")

exports.onPreInit = () =>
    console.info("Loaded gatsby-theme-onegeo", package_json.version)

exports.createPages = async function ({ actions, graphql }) {
    const { data } = await graphql(`
        query getPages {
            directus_system {
                settings {
                    version
                }
            }
            directus {
                pages {
                    id
                    slug
                }
                news {
                    id
                    slug
                    title
                    image {
                        id
                        imageFile {
                            publicURL
                        }
                    }
                }
            }
        }
    `)

    const api_version = semver.valid(data.directus_system?.settings?.version)
    const api_version_required = semver.validRange(
        package_json?.onegeosuite?.portal?.datamodel
    )

    console.info("Directus datamodel", api_version)
    console.info("Directus datamodel required", api_version_required)

    if (!api_version) {
        console.error(
            "Unable to get DataModel Version, Check Directus system settings."
        )
        process.exit(1)
    }
    if (!api_version_required) {
        console.error(
            "Unable to get required DataModel Version, Check project package.json (onegeosuite.portal.datamodel)."
        )
        process.exit(1)
    }
    if (!semver.satisfies(api_version, api_version_required)) {
        console.error(
            "Directus DataModel version " +
                api_version_required +
                " REQUIRED (found " +
                api_version +
                ")"
        )
        process.exit(1)
    }

    data.directus.pages.forEach((page) => {
        actions.createPage({
            path: `/${page.slug}`,
            component: require.resolve(`./src/templates/page.tsx`),
            context: {
                id: page.id,
            },
        })
    })

    data.directus.news.forEach((news, i) => {
        actions.createPage({
            path: `/news/${news.slug}`,
            component: require.resolve(`./src/templates/news.tsx`),
            context: {
                id: news.id,
                prev: data.directus.news.at(i - 1),
                next: data.directus.news.at(i + 1),
            },
        })
    })
}
